# Full USA English Parser

This is a full English Parser for USA English created by Amnon Meyers over the period of 20 years. It uses the older Wordnet dictionary for parts of speech.

## Wiktionary Update

Sometime in 2023, the plan is to have the English Wiktionary parsed in order to generate a much more ample English dictionary.
